@@ -84,7 +84,7 @@ wnck_application_get_type (void)
   
   if (!object_type)
     {
-      static const GTypeInfo object_info =
+      const GTypeInfo object_info =
       {
         sizeof (WnckApplicationClass),
         (GBaseInitFunc) NULL,
